@@ -69,7 +69,7 @@ extern int make_listening_socket(char const *str, int backlog, int must_be_unix)
 extern void do_delay(char const *sleepstr);
 extern int is_localhost(struct sockaddr *);
 extern int remove_local_socket(char const *str);
-extern int write_and_lock_pidfile(char const *pidfile, char *lockfile, int fd);
+extern int write_and_lock_pidfile(char const *pidfile, char **lockfile, int fd);
 #ifdef EMBED_PERL
 extern int make_embedded_interpreter(char const *progPath,
 				     char const *subFilter,
@@ -83,6 +83,18 @@ extern void dump_milter_buildlib_info(void);
 
 #endif
 
+#ifndef timespecsub
+#define timespecsub(tsp, usp, vsp)                          \
+    do {                                                    \
+        (vsp)->tv_sec = (tsp)->tv_sec - (usp)->tv_sec;      \
+        (vsp)->tv_nsec = (tsp)->tv_nsec - (usp)->tv_nsec;   \
+        if ((vsp)->tv_nsec < 0) {                           \
+            (vsp)->tv_sec--;                                \
+            (vsp)->tv_nsec += 1000000000L;                  \
+        }                                                   \
+    } while (0)
+#endif
+
 extern char *gen_mx_id(char *);
 /* Magic return values */
 #define MD_TEMPFAIL                    -1
